Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Braket.

Actions, resources, and condition keys for Amazon Braket - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Braket

Amazon Braket (service prefix: `braket` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Braket
- Resource types defined by Amazon Braket
- Condition keys for Amazon Braket

## Actions defined by Amazon Braket

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelJob | Grants permission to cancel a job | Write | job* |  |
CancelQuantumTask | Grants permission to cancel a quantum task | Write | quantum-task* |  |
CreateJob | Grants permission to create a job | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateQuantumTask | Grants permission to create a quantum task | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
GetDevice | Grants permission to retrieve information about the devices available in Amazon Braket | Read |  |  |
GetJob | Grants permission to retrieve jobs | Read | job* |  |
GetQuantumTask | Grants permission to retrieve quantum tasks | Read | quantum-task* |  |
ListTagsForResource | Grants permission to listing the tags that have been applied to the quantum task resource or the job | Read | job |  |
quantum-task |  |
SearchDevices | Grants permission to search for devices available in Amazon Braket | Read |  |  |
SearchJobs | Grants permission to search for jobs | Read |  |  |
SearchQuantumTasks | Grants permission to search for quantum tasks | Read |  |  |
TagResource | Grants permission to add one or more tags to a quantum task | Tagging | quantum-task |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove one or more tags from a quantum task resource or a job. A tag consists of a key-value pair | Tagging | job |  |
quantum-task |  |
| aws:TagKeys |

## Resource types defined by Amazon Braket

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
quantum-task | `arn:$ { Partition}:braket:$ { Region}:$ { Account}:quantum-task/$ { RandomId}` | aws:ResourceTag/${TagKey}
job | `arn:$ { Partition}:braket:$ { Region}:$ { Account}:job/$ { JobName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Braket

Amazon Braket defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.